| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Chart.Style
Description
Definition of the syntactical manifestation of chart elements.
Synopsis
- data Style = Style {
- size :: Double
- borderSize :: Double
- color :: Colour
- borderColor :: Colour
- scaleP :: ScaleP
- textAnchor :: TextAnchor
- rotation :: Maybe Double
- translate :: Maybe (Point Double)
- escapeText :: EscapeText
- frame :: Maybe Style
- lineCap :: Maybe LineCap
- lineJoin :: Maybe LineJoin
- dasharray :: Maybe [Double]
- dashoffset :: Maybe Double
- hsize :: Double
- vsize :: Double
- vshift :: Double
- glyphShape :: GlyphShape
- defaultStyle :: Style
- scaleStyle :: Double -> Style -> Style
- defaultRectStyle :: Style
- blob :: Colour -> Style
- clear :: Style
- border :: Double -> Colour -> Style
- defaultTextStyle :: Style
- styleBoxText :: Style -> Text -> Point Double -> Rect Double
- data EscapeText
- defaultGlyphStyle :: Style
- styleBoxGlyph :: Style -> Rect Double
- gpalette :: Int -> GlyphShape
- data GlyphShape
- defaultLineStyle :: Style
- data LineCap
- fromLineCap :: IsString s => LineCap -> s
- toLineCap :: (Eq s, IsString s) => s -> LineCap
- data LineJoin
- fromLineJoin :: IsString s => LineJoin -> s
- toLineJoin :: (Eq s, IsString s) => s -> LineJoin
- data TextAnchor
- fromTextAnchor :: TextAnchor -> ByteString
- fromAnchoring :: Double -> TextAnchor
- data Align
- defaultPathStyle :: Style
- data ScaleP
- scaleRatio :: ScaleP -> Rect Double -> Rect Double -> Double
Documentation
Stylistic content of chart elements, involving how chart data is represented in the physical chart.
>>>defaultStyleStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.02 0.73 0.80 0.10, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
Constructors
| Style | |
Fields
| |
Instances
defaultStyle :: Style Source #
The official default style
>>>defaultStyleStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.02 0.73 0.80 0.10, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
scaleStyle :: Double -> Style -> Style Source #
Scale the size, borderSize and any translations of a Style.
RectStyle
defaultRectStyle :: Style Source #
The official style for rectangles.
>>>defaultRectStyleStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.02 0.73 0.80 0.10, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
blob :: Colour -> Style Source #
solid rectangle, no border
>>>blob blackStyle {size = 6.0e-2, borderSize = 0.0, color = Colour 0.00 0.00 0.00 1.00, borderColor = Colour 0.00 0.00 0.00 0.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
transparent rect
>>>clearStyle {size = 6.0e-2, borderSize = 0.0, color = Colour 0.00 0.00 0.00 0.00, borderColor = Colour 0.00 0.00 0.00 0.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
border :: Double -> Colour -> Style Source #
transparent rectangle, with border
>>>border 0.01 transparentStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.00 0.00 0.00 0.00, borderColor = Colour 0.00 0.00 0.00 0.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
TextStyle
defaultTextStyle :: Style Source #
The official style for text elements.
>>>defaultTextStyleStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.05 0.05 0.05 1.00, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
styleBoxText :: Style -> Text -> Point Double -> Rect Double Source #
the extra area from text styling
data EscapeText Source #
Whether to escape the common XML escaped characters.
Constructors
| EscapeText | |
| NoEscapeText |
Instances
| Data EscapeText Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> EscapeText -> c EscapeText # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c EscapeText # toConstr :: EscapeText -> Constr # dataTypeOf :: EscapeText -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c EscapeText) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c EscapeText) # gmapT :: (forall b. Data b => b -> b) -> EscapeText -> EscapeText # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> EscapeText -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> EscapeText -> r # gmapQ :: (forall d. Data d => d -> u) -> EscapeText -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> EscapeText -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> EscapeText -> m EscapeText # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> EscapeText -> m EscapeText # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> EscapeText -> m EscapeText # | |||||
| Generic EscapeText Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show EscapeText Source # | |||||
Defined in Chart.Style Methods showsPrec :: Int -> EscapeText -> ShowS # show :: EscapeText -> String # showList :: [EscapeText] -> ShowS # | |||||
| Eq EscapeText Source # | |||||
Defined in Chart.Style | |||||
| type Rep EscapeText Source # | |||||
GlyphStyle
defaultGlyphStyle :: Style Source #
The official style for glyphs.
>>>defaultGlyphStyleStyle {size = 3.0e-2, borderSize = 3.0e-3, color = Colour 0.02 0.73 0.80 0.20, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
gpalette :: Int -> GlyphShape Source #
Infinite list of glyph shapes
>>>gpalette 0CircleGlyph
data GlyphShape Source #
glyph shapes
Constructors
| CircleGlyph | |
| SquareGlyph | |
| EllipseGlyph Double | |
| RectSharpGlyph Double | |
| RectRoundedGlyph Double Double Double | |
| TriangleGlyph (Point Double) (Point Double) (Point Double) | line width is determined by borderSize |
| VLineGlyph | |
| HLineGlyph | |
| PathGlyph ByteString |
Instances
| Data GlyphShape Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> GlyphShape -> c GlyphShape # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c GlyphShape # toConstr :: GlyphShape -> Constr # dataTypeOf :: GlyphShape -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c GlyphShape) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c GlyphShape) # gmapT :: (forall b. Data b => b -> b) -> GlyphShape -> GlyphShape # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> GlyphShape -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> GlyphShape -> r # gmapQ :: (forall d. Data d => d -> u) -> GlyphShape -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> GlyphShape -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> GlyphShape -> m GlyphShape # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> GlyphShape -> m GlyphShape # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> GlyphShape -> m GlyphShape # | |||||
| Generic GlyphShape Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show GlyphShape Source # | |||||
Defined in Chart.Style Methods showsPrec :: Int -> GlyphShape -> ShowS # show :: GlyphShape -> String # showList :: [GlyphShape] -> ShowS # | |||||
| Eq GlyphShape Source # | |||||
Defined in Chart.Style | |||||
| type Rep GlyphShape Source # | |||||
Defined in Chart.Style type Rep GlyphShape = D1 ('MetaData "GlyphShape" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) (((C1 ('MetaCons "CircleGlyph" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "SquareGlyph" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "EllipseGlyph" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)) :+: C1 ('MetaCons "RectSharpGlyph" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double)))) :+: ((C1 ('MetaCons "RectRoundedGlyph" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Double))) :+: C1 ('MetaCons "TriangleGlyph" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Point Double)) :*: (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Point Double)) :*: S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 (Point Double))))) :+: (C1 ('MetaCons "VLineGlyph" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "HLineGlyph" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "PathGlyph" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ByteString)))))) | |||||
LineStyle
defaultLineStyle :: Style Source #
The official style for lines.
>>>defaultLineStyleStyle {size = 1.2e-2, borderSize = 1.0e-2, color = Colour 0.05 0.05 0.05 1.00, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
line cap style
Constructors
| LineCapButt | |
| LineCapRound | |
| LineCapSquare |
Instances
| Data LineCap Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> LineCap -> c LineCap # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c LineCap # toConstr :: LineCap -> Constr # dataTypeOf :: LineCap -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c LineCap) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c LineCap) # gmapT :: (forall b. Data b => b -> b) -> LineCap -> LineCap # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> LineCap -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> LineCap -> r # gmapQ :: (forall d. Data d => d -> u) -> LineCap -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> LineCap -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> LineCap -> m LineCap # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> LineCap -> m LineCap # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> LineCap -> m LineCap # | |||||
| Generic LineCap Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show LineCap Source # | |||||
| Eq LineCap Source # | |||||
| type Rep LineCap Source # | |||||
Defined in Chart.Style type Rep LineCap = D1 ('MetaData "LineCap" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) (C1 ('MetaCons "LineCapButt" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "LineCapRound" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "LineCapSquare" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
fromLineCap :: IsString s => LineCap -> s Source #
svg textifier
line cap style
Constructors
| LineJoinMiter | |
| LineJoinBevel | |
| LineJoinRound |
Instances
| Data LineJoin Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> LineJoin -> c LineJoin # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c LineJoin # toConstr :: LineJoin -> Constr # dataTypeOf :: LineJoin -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c LineJoin) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c LineJoin) # gmapT :: (forall b. Data b => b -> b) -> LineJoin -> LineJoin # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> LineJoin -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> LineJoin -> r # gmapQ :: (forall d. Data d => d -> u) -> LineJoin -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> LineJoin -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> LineJoin -> m LineJoin # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> LineJoin -> m LineJoin # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> LineJoin -> m LineJoin # | |||||
| Generic LineJoin Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show LineJoin Source # | |||||
| Eq LineJoin Source # | |||||
| type Rep LineJoin Source # | |||||
Defined in Chart.Style type Rep LineJoin = D1 ('MetaData "LineJoin" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) (C1 ('MetaCons "LineJoinMiter" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "LineJoinBevel" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "LineJoinRound" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
fromLineJoin :: IsString s => LineJoin -> s Source #
svg textifier
Stack Styling
data TextAnchor Source #
Text Anchor
Constructors
| AnchorMiddle | |
| AnchorStart | |
| AnchorEnd |
Instances
| Data TextAnchor Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> TextAnchor -> c TextAnchor # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c TextAnchor # toConstr :: TextAnchor -> Constr # dataTypeOf :: TextAnchor -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c TextAnchor) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c TextAnchor) # gmapT :: (forall b. Data b => b -> b) -> TextAnchor -> TextAnchor # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> TextAnchor -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> TextAnchor -> r # gmapQ :: (forall d. Data d => d -> u) -> TextAnchor -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> TextAnchor -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> TextAnchor -> m TextAnchor # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> TextAnchor -> m TextAnchor # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> TextAnchor -> m TextAnchor # | |||||
| Generic TextAnchor Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show TextAnchor Source # | |||||
Defined in Chart.Style Methods showsPrec :: Int -> TextAnchor -> ShowS # show :: TextAnchor -> String # showList :: [TextAnchor] -> ShowS # | |||||
| Eq TextAnchor Source # | |||||
Defined in Chart.Style | |||||
| type Rep TextAnchor Source # | |||||
Defined in Chart.Style type Rep TextAnchor = D1 ('MetaData "TextAnchor" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) (C1 ('MetaCons "AnchorMiddle" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "AnchorStart" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AnchorEnd" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
fromTextAnchor :: TextAnchor -> ByteString Source #
Convert a TextAnchor to a ByteString label.
fromAnchoring :: Double -> TextAnchor Source #
Convert a Double to a TextAnchor
Aligning stacked things.
Constructors
| NoAlign | |
| AlignRight | |
| AlignLeft | |
| AlignMid |
Instances
| Data Align Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> Align -> c Align # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c Align # dataTypeOf :: Align -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c Align) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c Align) # gmapT :: (forall b. Data b => b -> b) -> Align -> Align # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> Align -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> Align -> r # gmapQ :: (forall d. Data d => d -> u) -> Align -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> Align -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> Align -> m Align # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> Align -> m Align # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> Align -> m Align # | |||||
| Generic Align Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show Align Source # | |||||
| Eq Align Source # | |||||
| type Rep Align Source # | |||||
Defined in Chart.Style type Rep Align = D1 ('MetaData "Align" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) ((C1 ('MetaCons "NoAlign" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AlignRight" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "AlignLeft" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "AlignMid" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
PathStyle
defaultPathStyle :: Style Source #
The official style for paths.
>>>defaultPathStyleStyle {size = 6.0e-2, borderSize = 1.0e-2, color = Colour 0.66 0.07 0.55 1.00, borderColor = Colour 0.02 0.29 0.48 1.00, scaleP = NoScaleP, textAnchor = AnchorMiddle, rotation = Nothing, translate = Nothing, escapeText = EscapeText, frame = Nothing, lineCap = Nothing, lineJoin = Nothing, dasharray = Nothing, dashoffset = Nothing, hsize = 0.6, vsize = 1.1, vshift = -0.25, glyphShape = SquareGlyph}
Style scaling
Scale Projection options
Constructors
| NoScaleP | Do not scale under projection. |
| ScalePX | Scale based on the X axis ratio of a projection |
| ScalePY | Scale based on the Y axis ratio of a projection |
| ScalePMinDim | Scale based on minimum of (X axis, Y axis) ratio |
| ScalePArea | Scale based on the area ratio of a projection |
Instances
| Data ScaleP Source # | |||||
Defined in Chart.Style Methods gfoldl :: (forall d b. Data d => c (d -> b) -> d -> c b) -> (forall g. g -> c g) -> ScaleP -> c ScaleP # gunfold :: (forall b r. Data b => c (b -> r) -> c r) -> (forall r. r -> c r) -> Constr -> c ScaleP # toConstr :: ScaleP -> Constr # dataTypeOf :: ScaleP -> DataType # dataCast1 :: Typeable t => (forall d. Data d => c (t d)) -> Maybe (c ScaleP) # dataCast2 :: Typeable t => (forall d e. (Data d, Data e) => c (t d e)) -> Maybe (c ScaleP) # gmapT :: (forall b. Data b => b -> b) -> ScaleP -> ScaleP # gmapQl :: (r -> r' -> r) -> r -> (forall d. Data d => d -> r') -> ScaleP -> r # gmapQr :: forall r r'. (r' -> r -> r) -> r -> (forall d. Data d => d -> r') -> ScaleP -> r # gmapQ :: (forall d. Data d => d -> u) -> ScaleP -> [u] # gmapQi :: Int -> (forall d. Data d => d -> u) -> ScaleP -> u # gmapM :: Monad m => (forall d. Data d => d -> m d) -> ScaleP -> m ScaleP # gmapMp :: MonadPlus m => (forall d. Data d => d -> m d) -> ScaleP -> m ScaleP # gmapMo :: MonadPlus m => (forall d. Data d => d -> m d) -> ScaleP -> m ScaleP # | |||||
| Generic ScaleP Source # | |||||
Defined in Chart.Style Associated Types
| |||||
| Show ScaleP Source # | |||||
| Eq ScaleP Source # | |||||
| type Rep ScaleP Source # | |||||
Defined in Chart.Style type Rep ScaleP = D1 ('MetaData "ScaleP" "Chart.Style" "chart-svg-0.8.3.2-HqC5koQF24PBkrFlIP6qwR" 'False) ((C1 ('MetaCons "NoScaleP" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "ScalePX" 'PrefixI 'False) (U1 :: Type -> Type)) :+: (C1 ('MetaCons "ScalePY" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "ScalePMinDim" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "ScalePArea" 'PrefixI 'False) (U1 :: Type -> Type)))) | |||||